==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Экспортировать как растровое изображение</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Ошибка генерации файла растрового изображения &apos;%1: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Растровый файл был экспортирован в &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Экспорт растрового изображения</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Пикселей на единицу измерения чертежа:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Поле:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>пикс.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Белый</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Чёрный</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Экспорт растрового изображения...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+119"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Экспортировать как растровое изображение</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Ошибка генерации файла растрового изображения &apos;%1: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Растровый файл был экспортирован в &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Экспорт растрового изображения</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Пикселей на единицу измерения чертежа:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Export bounding box of selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Transparent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+23"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Monochrome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Anti-aliasing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use anti-aliasing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Margin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin:</source>
        <translation>Поле:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>px</source>
        <translation>пикс.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add extra margin to compensate for line weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-170"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Белый</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Чёрный</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Экспорт растрового изображения...</translation>
    </message>
</context>
<context>
    <name>BitmapExportWorker</name>
    <message>
        <location filename="../BitmapExportWorker.js" line="+106"/>
        <source>Invalid image size (width x height must be less than %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
